# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [2.0.6] - 2026-02-19

### Fixed
- Update / create map request data

## [2.0.5] - 2026-02-18

### Changed
- Bump version to v2.0.5 by @github-actions[bot]
- Update lock file

### Fixed
- Set job id

## [2.0.4] - 2026-02-17

### Added
- Add backend for the import jobs to handle the location header

### Changed
- Bump version to v2.0.4 by @github-actions[bot]

## [2.0.3] - 2026-02-17

### Changed
- Bump version to v2.0.3 by @github-actions[bot]
- Update all docstrings examples
- Update configs.json

### Fixed
- Sbom-test class exclude due build configurtion

## [2.0.2] - 2026-02-16

### Added
- Add snyk import project models

### Changed
- Bump version to v2.0.2 by @github-actions[bot]

### Fixed
- Fix uneeded pyproject.toml for doc

## [2.0.1] - 2026-02-10

### Added
- Add flags for delete, create, update, query

### Changed
- Bump version to v2.0.1 by @github-actions[bot]
- Linting
- Update readme
- Setup the snyk module

### Removed
- Remove circular dependency injenction

## New Contributors
* @github-actions[bot] made their first contribution
* @ made their first contribution
[2.0.6]: https://github.com/clearskies-py/snyk/compare/v2.0.5..v2.0.6
[2.0.5]: https://github.com/clearskies-py/snyk/compare/v2.0.4..v2.0.5
[2.0.4]: https://github.com/clearskies-py/snyk/compare/v2.0.3..v2.0.4
[2.0.3]: https://github.com/clearskies-py/snyk/compare/v2.0.2..v2.0.3
[2.0.2]: https://github.com/clearskies-py/snyk/compare/v2.0.1..v2.0.2

<!-- generated by git-cliff -->
